# fotolab

A console program to manipulate photos.

## Installation

Stable version From PyPI using `pipx`:

```console
pipx install fotolab
```

Stable version From PyPI using `pip`:

```console
python -m pip install fotolab
```

Latest development version from GitHub:

```console
python -m pip install -e git+https://github.com/kianmeng/fotolab.git
```

## Usage

```console
fotolab -h
```

```console
usage: fotolab [-h] [-q] [-d] [-V] {watermark} ...

A console program to manipulate photos.

  website: https://github.com/kianmeng/fotolab
  changelog: https://github.com/kianmeng/fotolab/blob/master/CHANGELOG.md
  issues: https://github.com/kianmeng/fotolab/issues

positional arguments:
  {watermark}    sub-command help
    watermark    watermark an image

options:
  -h, --help     show this help message and exit
  -q, --quiet    suppress all logging
  -d, --debug    show debugging log and stacktrace
  -V, --version  show program's version number and exit
```

### fotolab watermark

```console
fotolab watermark -h
```

```console
usage: fotolab watermark [-h] [-t WATERMARK_TEXT]
                         [-p {top-left,top-right,bottom-left,bottom-right}]
                         [-fs FONT_SIZE] [-fc FONT_SIZE] [-ow OUTLINE_WIDTH]
                         [-oc OUTLINE_COLOR]
                         IMAGE_FILENAME

positional arguments:
  IMAGE_FILENAME        set the image filename

options:
  -h, --help            show this help message and exit
  -t WATERMARK_TEXT, --text WATERMARK_TEXT
                        set the watermark text (default: 'kianmeng.org')
  -p {top-left,top-right,bottom-left,bottom-right}, --position {top-left,top-right,bottom-left,bottom-right}
                        set position of the watermark text (default: 'bottom-
                        left')
  -fs FONT_SIZE, --font-size FONT_SIZE
                        set the font size of watermark text (default: '12')
  -fc FONT_SIZE, --font-color FONT_SIZE
                        set the font color of watermark text (default:
                        'white')
  -ow OUTLINE_WIDTH, --outline-width OUTLINE_WIDTH
                        set the outline width of the watermark text (default:
                        '2')
  -oc OUTLINE_COLOR, --outline-color OUTLINE_COLOR
                        set the outline color of the watermark text (default:
                        'black')
```

## Copyright and License

Copyright (C) 2024 Kian-Meng Ang

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License along
with this program. If not, see <https://www.gnu.org/licenses/>.
